<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package WP Blogger
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>

</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'wp-blogger' ); ?></a>

	<!-- #masthead, site-header-1-0-->
	<header id="masthead" class="site-header site-header-1-0">

		<div class="site-branding">
			<?php
			the_custom_logo();
			?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
			<?php
			$description = get_bloginfo( 'description', 'display' );
			if ( $description || is_customize_preview() ) : ?>
				<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
			<?php
			endif; ?>
		</div><!-- .site-branding -->

		<div class="container container-main-navigation">
			<div class="row">
				<div class="col-xs-12">

					<!-- Hambuger Menu -->
					<label>
						<input type='checkbox'>
							<span class='menu'>
							  <span class='hamburger'></span>
							</span>
						<ul>
  							<?php
							wp_nav_menu( array(
								'theme_location' => 'menu-2',
								'menu_id'        => '',
								'depth'             => 3,
								'container_class'   => '',
								'container_id'      => '',
								 'container'       => false,
  								'echo'            => true,
  								'items_wrap'      => '%3$s',

							) );
						?>
						</ul>
					</label><!-- .Hambuger Menu -->

					<!-- #site-navigation -->
					<nav id="site-navigation" class="main-navigation">

						<button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#primary-menu" aria-expanded="false">
						  <span class="sr-only"><?php echo esc_html__( 'Toggle navigation', 'wp-blogger' ); ?></span>
		                  <span class="icon-bar"></span>
		                  <span class="icon-bar"></span>
		                  <span class="icon-bar"></span>
		                </button>

						<?php
							wp_nav_menu( array(
								'theme_location' => 'menu-1',
								'menu_id'        => 'primary-menu',
								'depth'             => 3,
								'container_class'   => 'collapse navbar-collapse',
								'container_id'      => 'primary-menu',

							) );
						?>
					</nav><!-- #site-navigation -->

					<!-- Search -->
					<div class="hdr-search">
						<a href="#search"><i class="ti-search"></i></a>
					</div><!-- .Search -->

					<div id="search">
					    <button type="button" class="close"><?php echo esc_attr('X','wp-blogger'); ?></button>
					   	<?php get_search_form() ?>
					</div>

				</div>
			</div>
		</div>

		<div class="site-header-bg">
			<?php if(has_header_image()): 
				echo esc_url(get_header_image()); 
			 else: 
			 ?>
			<img src="<?php echo esc_url(get_template_directory_uri());?>/wpcodethemes/assets/img/site-header-bg.jpg" alt="<?php bloginfo('name'); ?>"/>
		<?php endif; ?>
		</div>

	</header><!-- /#masthead, site-header-1-0-->

	<?php
		if(!is_single() || is_page()):
			get_template_part( 'home-sections/section', 'header' );
		endif;
	?>

	<div id="content" class="site-content site-content-1-0">
