<?php
/**
 * WP Blogger Theme Customizer
 *
 * @package WP Blogger
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param wp_Customize_Manager $wp_customize Theme Customizer object.
 */
function wp_blogger_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Sanitization Callback
	require_once trailingslashit( get_template_directory() ) . '/inc/sanitize.php'; 

	// Customizer Options
	require_once trailingslashit( get_template_directory() ) . '/inc/customizer-options.php';

	// Customizer Options
	require_once trailingslashit( get_template_directory() ) . '/inc/customizer-socials.php'; 
		//Customizer Home Page Options
	require_once trailingslashit( get_template_directory() ) . '/inc/upgrade-to-pro/control.php';

	//Upgrade to Pro
	// Register custom section types.
	$wp_customize->register_section_type( 'wp_blogger_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new wp_blogger_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Go Pro', 'wp-blogger' ),
				'pro_text' => esc_html__( 'Buy WP Blogger Pro', 'wp-blogger' ),
				'pro_url'  => 'https://wpcodefactory.com/item/wp-blogger-plus-wordpress-theme',
				'priority' => 1,
			)
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'wp_blogger_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'wp_blogger_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'wp_blogger_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function wp_blogger_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function wp_blogger_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wp_blogger_customize_preview_js() {
	wp_enqueue_script( 'WP Blogger-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'wp_blogger_customize_preview_js' );

function wp_blogger_customizer_control_scripts() {

	wp_enqueue_script( 'wp-blogger-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/customize-controls.js', array( 'customize-controls' ) );

	wp_enqueue_style( 'wp-blogger-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/customize-controls.css' );

}

add_action( 'customize_controls_enqueue_scripts', 'wp_blogger_customizer_control_scripts', 0 );
